@@ -1,5 +1,4 @@
 package App::PerlNitpick::Rule::RewriteWithAssignmentOperators;
-
 use Moose;
 use PPI::Document;
 use PPI::Token::Whitespace;
@@ -10,21 +9,24 @@ sub rewrite {
     my ($self, $document) = @_;
 
     my @found = grep {
-        my $c1 = $_->schild(0);
-        my $c2 = $_->schild(2);
-        $c1->isa('PPI::Token::Symbol') && $c1->raw_type eq '$' &&
+        # Find a statement that looks like $x = $x + $y;
+        my $c0 = $_->schild(0);  # $x
+        my $c1 = $_->schild(1);  # =
+        my $c2 = $_->schild(2);  # $x
+        my $c3 = $_->schild(3);  # +
+        my $c4 = $_->schild(4);  # $y
+        my $c5 = $_->schild(5);  # ;
+
+        ($c1->isa('PPI::Token::Operator') && $c1->content eq '=') &&
+        ($c5->isa('PPI::Token::Structure') && $c5->content eq ';') &&
+        ($c3->isa('PPI::Token::Operator') && $c3->content !~ m{\A( -> | > | < | \.)\z}x) &&
+        ($c0->isa('PPI::Token::Symbol') && $c0->raw_type eq '$' &&
         $c2->isa('PPI::Token::Symbol') && $c2->raw_type eq '$' &&
-        $c1->content && $c2->content
-    } grep {
-        my $c = $_->schild(3);
-        $c->isa('PPI::Token::Operator') && $c->content !~ m{\A( -> | > | < )\z}x;
-    } grep {
-        my $c = $_->schild(1);
-        $c->isa('PPI::Token::Operator') && $c->content eq '='
+        $c1->content && $c2->content)
     } grep {
         $_->schildren == 6
     } @{ $document->find('PPI::Statement') ||[] };
-    
+
     return $document unless @found;
 
     for my $statement (@found) {
